==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/identitystore/kotlin/inputs/GetGroupAlternateIdentifierUniqueAttribute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.identitystore.kotlin.inputs

import com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property attributePath Attribute path that is used to specify which attribute name to search. For example: `DisplayName`. Refer to the [Group data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_Group.html).
 * @property attributeValue Value for an attribute.
 */
public data class GetGroupAlternateIdentifierUniqueAttribute(
    public val attributePath: String,
    public val attributeValue: String,
) :
    ConvertibleToJava<com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute> {
    override fun toJava():
        com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute =
        com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute.builder()
            .attributePath(attributePath.let({ args0 -> args0 }))
            .attributeValue(attributeValue.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGroupAlternateIdentifierUniqueAttribute].
 */
@PulumiTagMarker
public class GetGroupAlternateIdentifierUniqueAttributeBuilder internal constructor() {
    private var attributePath: String? = null

    private var attributeValue: String? = null

    /**
     * @param value Attribute path that is used to specify which attribute name to search. For example: `DisplayName`. Refer to the [Group data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_Group.html).
     */
    @JvmName("asanmiedvvpgvwet")
    public suspend fun attributePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributePath = mapped
    }

    /**
     * @param value Value for an attribute.
     */
    @JvmName("lcnniqtvmentibie")
    public suspend fun attributeValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributeValue = mapped
    }

    internal fun build(): GetGroupAlternateIdentifierUniqueAttribute =
        GetGroupAlternateIdentifierUniqueAttribute(
            attributePath = attributePath ?: throw PulumiNullFieldException("attributePath"),
            attributeValue = attributeValue ?: throw PulumiNullFieldException("attributeValue"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/identitystore/kotlin/inputs/GetGroupAlternateIdentifierUniqueAttribute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.identitystore.kotlin.inputs

import com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property attributePath Attribute path that is used to specify which attribute name to search. For example: `DisplayName`. Refer to the [Group data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_Group.html).
 * @property attributeValue Value for an attribute.
 */
public data class GetGroupAlternateIdentifierUniqueAttribute(
    public val attributePath: String,
    public val attributeValue: String,
) :
    ConvertibleToJava<com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute> {
    override fun toJava(): com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute =
        com.pulumi.aws.identitystore.inputs.GetGroupAlternateIdentifierUniqueAttribute.builder()
            .attributePath(attributePath.let({ args0 -> args0 }))
            .attributeValue(attributeValue.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGroupAlternateIdentifierUniqueAttribute].
 */
@PulumiTagMarker
public class GetGroupAlternateIdentifierUniqueAttributeBuilder internal constructor() {
    private var attributePath: String? = null

    private var attributeValue: String? = null

    /**
     * @param value Attribute path that is used to specify which attribute name to search. For example: `DisplayName`. Refer to the [Group data type](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_Group.html).
     */
    @JvmName("qejvporeuochhvqq")
    public suspend fun attributePath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributePath = mapped
    }

    /**
     * @param value Value for an attribute.
     */
    @JvmName("lioasebowqvbmclk")
    public suspend fun attributeValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.attributeValue = mapped
    }

    internal fun build(): GetGroupAlternateIdentifierUniqueAttribute =
        GetGroupAlternateIdentifierUniqueAttribute(
            attributePath = attributePath ?: throw PulumiNullFieldException("attributePath"),
            attributeValue = attributeValue ?: throw PulumiNullFieldException("attributeValue"),
        )
}
